@@ -16,6 +16,7 @@ class DefaultConditioner:
         if not len(domain) == 1:
             return ("1 = 1", tuple())
         value = domain[0][2]
-        if not isinstance(domain[0][2], (list, tuple)):
-            value = [domain[0][2]]
-        return (f'{domain[0][0]} = ANY(ARRAY{str(value)})', tuple(value))
+        container = isinstance(
+            value, (list, tuple)) and value or [domain[0][2]]
+        return (f'{domain[0][0]} = ANY(ARRAY{str(container)})',
+                tuple(container))
